//
//  CPDFAnnotationBar.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFAnnotationBar.h"
#import "CPDFAnnotationBarButton.h"
#import "CPDFNoteViewController.h"
#import "CPDFHighlightViewController.h"
#import "CPDFStrikeoutViewController.h"
#import "CPDFSquigglyViewController.h"
#import "CPDFInkViewController.h"
#import "CPDFShapeCircleViewController.h"
#import "CPDFShapeArrowViewController.h"
#import "CAnnotStyle.h"
#import "CPDFListView.h"
#import "CAnnotationManage.h"
#import "CPDFNoteOpenViewController.h"

#import <ComPDFKit/ComPDFKit.h>

@interface CPDFAnnotationBar () <CPDFListViewDelegate, CPDFNoteOpenViewControllerDelegate>

@property (nonatomic, strong) UIScrollView *scrollView;

@property (nonatomic, strong) NSArray *annotationBtns;

@property (nonatomic, assign) NSInteger selectedIndex;

@property (nonatomic, strong) UIView *propertiesBar;

@property (nonatomic, strong) UIButton *propertiesBtn;

@property (nonatomic, strong) UIButton *undoBtn;

@property (nonatomic, strong) UIButton *redoBtn;

@property (nonatomic, strong) CPDFListView *pdfListView;

@property (nonatomic, strong) CAnnotationManage *annotManage;

@end

@implementation CPDFAnnotationBar

#pragma mark - Initializers

- (instancetype)initPDFView:(CPDFListView *)pdfListView {
    if (self = [super init]) {
        UIBlurEffect *blur = [UIBlurEffect effectWithStyle:UIBlurEffectStyleExtraLight];
        UIVisualEffectView *effectView = [[UIVisualEffectView alloc] initWithEffect:blur];
        effectView.frame = self.bounds;
        effectView.autoresizingMask = UIViewAutoresizingFlexibleWidth|UIViewAutoresizingFlexibleHeight;
        [self addSubview:effectView];
        
        UIView *line = [[UIView alloc] initWithFrame:CGRectMake(0, 0, self.frame.size.width, 1)];
        line.backgroundColor = [UIColor colorWithRed:210.0/255.0 green:210.0/255.0 blue:210.0/255.0 alpha:1.0];
        line.autoresizingMask = UIViewAutoresizingFlexibleWidth;
        [self addSubview:line];
        
        self.selectedIndex = -1;
        
        self.pdfListView = pdfListView;
        self.pdfListView.performDelegate = self;

        [self initSubview];
    }
    return self;
}

- (void)layoutSubviews {
    [super layoutSubviews];
    self.scrollView.frame = self.bounds;
}

#pragma mark - Public Methods

- (void)reloadData {
    if (self.selectedIndex >=0 &&
        self.selectedIndex < self.annotationBtns.count) {
        UIButton *selectedButton = [self.annotationBtns objectAtIndex:self.selectedIndex];
        selectedButton.backgroundColor = [UIColor clearColor];
    }
    self.selectedIndex = -1;
}

#pragma mark - Private Methods

- (void)initSubview {
    _scrollView = [[UIScrollView alloc] initWithFrame:self.bounds];
    _scrollView.showsVerticalScrollIndicator = NO;
    _scrollView.showsHorizontalScrollIndicator = NO;
    [self addSubview:_scrollView];
    
    CGFloat offsetX = 0.0;
    NSArray *images = @[@"CPDFAnnotationBarImageNote",
                        @"CPDFAnnotationBarImageHighLight",
                        @"CPDFAnnotationBarImageUnderline",
                        @"CPDFAnnotationBarImageStrikeout",
                        @"CPDFAnnotationBarImageSquiggly",
                        @"CPDFAnnotationBarImageFreehand",
                        @"CPDFAnnotationBarImageShapeCircle",
                        @"CPDFAnnotationBarImageShapeRectangle",
                        @"CPDFAnnotationBarImageShapeArrow",
                        @"CPDFAnnotationBarImageShapeLine",
                        @"CPDFAnnotationBarImageFreeText",
                        @"CPDFAnnotationBarImageSignature",
                        @"CPDFAnnotationBarImageStamp",
                        @"CPDFAnnotationBarImageImage",
                        @"CPDFAnnotationBarImageLink",
                        @"CPDFAnnotationBarImageSound"];
    
    NSMutableArray *annotationBtns = [NSMutableArray array];
    for (int i = 0; i < images.count; i++) {
        CPDFAnnotationBarButton *button = [CPDFAnnotationBarButton buttonWithType:UIButtonTypeCustom];
        button.frame = CGRectMake(offsetX, 1, 58, 43);
        [button setImage:[UIImage imageNamed:images[i] inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
        button.tag = i;
        button.type = i;
        if (i == 1) {
            button.lineColor = CPDFKitShareConfig.highlightAnnotationColor;
        } else if (i == 2) {
            button.lineColor = CPDFKitShareConfig.underlineAnnotationColor;
        } else if (i == 3) {
            button.lineColor = CPDFKitShareConfig.strikeoutAnnotationColor;
        } else if (i == 4) {
            button.lineColor = CPDFKitShareConfig.squigglyAnnotationColor;
        } else if (i == 5) {
            button.type = 4;
            button.lineColor = CPDFKitShareConfig.freehandAnnotationColor;
        }
        [button addTarget:self action:@selector(buttonItemClicked_Switch:) forControlEvents:UIControlEventTouchUpInside];
        [_scrollView addSubview:button];
        [annotationBtns addObject:button];
        
        if (UIUserInterfaceIdiomPhone == UI_USER_INTERFACE_IDIOM()) {
            offsetX += button.bounds.size.width;
        } else {
            offsetX += button.bounds.size.height;
        }
    }
    self.annotationBtns = annotationBtns;
    
    if (UIUserInterfaceIdiomPhone == UI_USER_INTERFACE_IDIOM()) {
        _scrollView.contentSize = CGSizeMake(offsetX, _scrollView.bounds.size.height);
    } else {
        _scrollView.contentSize = CGSizeMake(_scrollView.bounds.size.width, offsetX);
    }
    [self.scrollView bringSubviewToFront:self.propertiesBar];
    
    _propertiesBar = [[UIView alloc] initWithFrame:CGRectMake(self.bounds.size.width - 180, 0, 180, 44)];
    _propertiesBar.autoresizingMask = UIViewAutoresizingFlexibleLeftMargin;
    _propertiesBar.backgroundColor = [UIColor grayColor];
    [self addSubview:self.propertiesBar];
    
    _propertiesBtn = [[UIButton alloc] initWithFrame:CGRectMake(0, 1, 60, 43)];
    [_propertiesBtn setImage:[UIImage imageNamed:@"CPDFAnnotationBarImageProperties" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    _propertiesBtn.userInteractionEnabled = NO;
    [_propertiesBtn addTarget:self action:@selector(buttonItemClicked_open:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.propertiesBtn];
    
    _undoBtn = [[UIButton alloc] initWithFrame:CGRectMake(60, 1, 60, 43)];
    [_undoBtn setImage:[UIImage imageNamed:@"CPDFAnnotationBarImageUndo" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [_undoBtn addTarget:self action:@selector(buttonItemClicked_undo:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.undoBtn];
    
    _redoBtn = [[UIButton alloc] initWithFrame:CGRectMake(120, 1, 60, 43)];
    [_redoBtn setImage:[UIImage imageNamed:@"CPDFAnnotationBarImageRedo" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
    [_redoBtn addTarget:self action:@selector(buttonItemClicked_redo:) forControlEvents:UIControlEventTouchUpInside];
    [self.propertiesBar addSubview:self.redoBtn];
}

#pragma mark - Action

- (void)buttonItemClicked_Switch:(UIButton *)button {
    self.propertiesBtn.userInteractionEnabled = YES;
    self.propertiesBtn.tag = button.tag;
    if (self.selectedIndex >= 0 && self.selectedIndex < self.annotationBtns.count) {
        UIButton *selectButton = [self.annotationBtns objectAtIndex:self.selectedIndex];
        selectButton.backgroundColor = [UIColor clearColor];
    }
    
    if (button.tag != self.selectedIndex) {
        button.backgroundColor = [UIColor colorWithRed:178.0/255.0 green:239.0/255.0 blue:253.0/255.0 alpha:1.0];
        self.selectedIndex = button.tag;
    } else {
        self.selectedIndex = -1;
    }
    
    switch (self.selectedIndex) {
        case CPDFToolbarNote:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeNote;
        }
            break;
        case CPDFToolbarHighlight:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeHighlight;
        }
            break;
        case CPDFToolbarUnderline:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeUnderline;
        }
            break;
        case CPDFToolbarStrikeout:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeStrikeout;
        }
            break;
        case CPDFToolbarSquiggly:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeSquiggly;
        }
            break;
        case CPDFToolbarFreehand:
        {
            
        }
            break;
        case CPDFToolbarShapeCircle:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeCircle;
        }
            break;
        case CPDFToolbarShapeRectangle:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeSquare;
        }
            break;
        case CPDFToolbarShapeArrow:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeArrow;
        }
            break;
            
        default:
        {
            self.pdfListView.annotationMode = CPDFViewAnnotationModeNone;
        }
            break;
    }
}

- (void)buttonItemClicked_open:(UIButton *)button {
    CAnnotStyle *annotStytle = [[CAnnotStyle alloc] init];
    AAPLCustomPresentationController *presentationController NS_VALID_UNTIL_END_OF_SCOPE;
    switch (button.tag) {
        case CPDFToolbarNote:
        {
            CPDFNoteViewController *noteVC = [[CPDFNoteViewController alloc] initWithStyle:annotStytle];

            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:noteVC presentingViewController:self.parentVC];
            noteVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:noteVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarHighlight:
        {
            CPDFHighlightViewController *highlightVC = [[CPDFHighlightViewController alloc] initWithStyle:annotStytle];

            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:highlightVC presentingViewController:self.parentVC];
            highlightVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:highlightVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarUnderline:
        {
            CPDFUnderlineViewController *underlineVC = [[CPDFUnderlineViewController alloc] initWithStyle:annotStytle];

            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:underlineVC presentingViewController:self.parentVC];
            underlineVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:underlineVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarStrikeout:
        {
            CPDFStrikeoutViewController *strikeoutVC = [[CPDFStrikeoutViewController alloc] initWithStyle:annotStytle];

            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:strikeoutVC presentingViewController:self.parentVC];
            strikeoutVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:strikeoutVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarSquiggly:
        {
            CPDFSquigglyViewController *squigglyVC = [[CPDFSquigglyViewController alloc] initWithStyle:annotStytle];

            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:squigglyVC presentingViewController:self.parentVC];
            squigglyVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:squigglyVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarFreehand:
        {
            CPDFInkViewController *inkVC = [[CPDFInkViewController alloc] initWithStyle:annotStytle];
            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:inkVC presentingViewController:self.parentVC];
            inkVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:inkVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarShapeCircle:
        {
            CPDFShapeCircleViewController *circleVC = [[CPDFShapeCircleViewController alloc] initWithStyle:annotStytle selectIndex:CPDFToolbarShapeCircle title:@"Circle"];
            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:circleVC presentingViewController:self.parentVC];
            circleVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:circleVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarShapeRectangle:
        {
            CPDFShapeCircleViewController *circleVC = [[CPDFShapeCircleViewController alloc] initWithStyle:annotStytle selectIndex:CPDFToolbarShapeRectangle title:@"Rectangle"];
            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:circleVC presentingViewController:self.parentVC];
            circleVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:circleVC animated:YES completion:nil];
        }
            break;
        case CPDFToolbarShapeArrow:
        {
            CPDFShapeArrowViewController *arrowVC = [[CPDFShapeArrowViewController alloc] initWithStyle:annotStytle selectIndex:CPDFToolbarShapeArrow title:@"Arrow"];
            presentationController = [[AAPLCustomPresentationController alloc] initWithPresentedViewController:arrowVC presentingViewController:self.parentVC];
            arrowVC.transitioningDelegate = presentationController;
            [self.parentVC presentViewController:arrowVC animated:YES completion:nil];
        }
            break;
        default:
            break;
    }
}

- (void)buttonItemClicked_undo:(UIButton *)button {
    
}

- (void)buttonItemClicked_redo:(UIButton *)button {
    
}

#pragma mark - CPDFListViewDelegate

- (void)PDFViewPerformOpenNote:(CPDFListView *)pdfView forAnnotation:(CPDFAnnotation *)annotation {
    CGRect rect = [pdfView convertRect:annotation.bounds fromPage:annotation.page];
    CPDFNoteOpenViewController *noteOpenVC = [[CPDFNoteOpenViewController alloc] init];
    noteOpenVC.delegate = self;
    [noteOpenVC setContent:annotation.contents];
    [noteOpenVC showViewController:self.parentVC inRect:rect];
    
    self.annotManage = [[CAnnotationManage alloc] initWithPDFView:pdfView annotation:annotation];
}

#pragma mark - CPDFNoteOpenViewControllerDelegate

- (void)getNoteOpenViewController:(CPDFNoteOpenViewController *)noteOpenVC content:(NSString *)content isDelete:(BOOL)isDelete {
    if (isDelete) {
        [self.annotManage.annotation.page removeAnnotation:self.annotManage.annotation];
        [self.pdfListView setNeedsDisplayForPage:self.annotManage.annotation.page];
    } else {
        self.annotManage.annotation.contents = content;
    }
}

@end
