//
//  CPDFColorPickerView.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import "CPDFColorSelectView.h"

@interface  CPDFColorSelectView ()

@property (nonatomic, strong) UIView *colorPickerView;

@end

@implementation CPDFColorSelectView

#pragma mark - Initializers

- (instancetype)initWithFrame:(CGRect)frame {
    if (self = [super initWithFrame:frame]) {
        self.colorLabel = [[UILabel alloc] initWithFrame:CGRectMake(5, 0, 50, 30)];
        self.colorLabel.autoresizingMask = UIViewAutoresizingFlexibleRightMargin;
        self.colorLabel.text = NSLocalizedString(@"Fill:", nil);
        self.colorLabel.adjustsFontSizeToFitWidth = YES;
        [self addSubview:self.colorLabel];
        
        self.colorPickerView = [[UIView alloc] initWithFrame:CGRectMake(0, 30, self.bounds.size.width, 60)];
        [self pickerBarInit];
        self.colorPickerView.autoresizingMask = UIViewAutoresizingFlexibleWidth;
        [self addSubview:self.colorPickerView];
    }
    return self;
}

- (void)pickerBarInit {
    NSArray *colors = @[[UIColor grayColor],
                        [UIColor redColor],
                        [UIColor yellowColor],
                        [UIColor blueColor],
                        [UIColor colorWithRed:153.0/255.0 green:207.0/255.0 blue:161.0/255.0 alpha:1.0],
                        [UIColor clearColor]];
    for (int i = 0; i < 6; i++) {
        UIButton *button = [[UIButton alloc] initWithFrame:CGRectMake((self.bounds.size.width - 300)/7 * (i+1) + 50 * i, 5, 50, 50)];
        [[button layer] setCornerRadius:25];
        button.autoresizingMask = UIViewAutoresizingFlexibleRightMargin | UIViewAutoresizingFlexibleLeftMargin;
        button.backgroundColor = colors[i];
        button.tag = i;
        [button addTarget:self action:@selector(buttonItemClicked_select:) forControlEvents:UIControlEventTouchUpInside];
        if (i == 5) {
            [button setBackgroundImage:[UIImage imageNamed:@"CPDFColorSelectViewImageColor" inBundle:[NSBundle bundleForClass:self.class] compatibleWithTraitCollection:nil] forState:UIControlStateNormal];
        }
        [self.colorPickerView addSubview:button];
    }
}

#pragma mark - Action

- (void)buttonItemClicked_select:(UIButton *)button {
    switch (button.tag) {
        case 0 ... 4:
        {
            if (self.delegate && [self.delegate respondsToSelector:@selector(selectColorView:color:)]) {
                [self.delegate selectColorView:self color:button.backgroundColor];
            }
        }
            break;
        case 5:{
            if ([self.delegate respondsToSelector:@selector(selectColorView:)]) {
                [self.delegate selectColorView:self];
            }
            break;
        }

        default:
            break;
    }
}

@end
