//
//  CPDFListView.h
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//  This notice may not be removed from this file.
//

#import <ComPDFKit/ComPDFKit.h>

NS_ASSUME_NONNULL_BEGIN

typedef NS_ENUM(NSUInteger, CToolModel) {
    CToolModelViewer,
    CToolModelAnnotation,
    CToolModelForm,
    CToolModelEdit,
};

typedef NS_ENUM(NSInteger, CPDFViewAnnotationMode) {
    CPDFViewAnnotationModeNone = 0,
    CPDFViewAnnotationModeNote,
    CPDFViewAnnotationModeHighlight,
    CPDFViewAnnotationModeUnderline,
    CPDFViewAnnotationModeStrikeout,
    CPDFViewAnnotationModeSquiggly,
    CPDFViewAnnotationModeCircle,
    CPDFViewAnnotationModeSquare,
    CPDFViewAnnotationModeArrow,
    CPDFViewAnnotationModeLine,
    CPDFViewAnnotationModeInk,
    CPDFViewAnnotationModeFreeText,
    CPDFViewAnnotationModeStamp,
    CPDFViewAnnotationModeImage,
    CPDFViewAnnotationModeLink,
    CPDFViewAnnotationModeSound
};

#pragma mark - CPDFListViewDelegate

@class CPDFListView;

@protocol CPDFListViewDelegate <NSObject>

@optional

- (NSArray<UIMenuItem *> *)PDFListView:(CPDFListView *)pdfListView customizeMenuForPage:(CPDFPage *)page forPagePoint:(CGPoint)pagePoint;

- (void)PDFViewPerformOpenNote:(CPDFListView *)pdfView forAnnotation:(CPDFAnnotation *)annotation;

@end

#pragma mark - CPDFListView

@interface CPDFListView : CPDFView

@property (nonatomic, weak) id<CPDFListViewDelegate> performDelegate;

@property (nonatomic, assign) CToolModel toolModel;

@property (nonatomic, assign) CPDFViewAnnotationMode annotationMode;

@property (nullable, nonatomic, strong) CPDFAnnotation *activeAnnotation;

@property (nonatomic, strong) CPDFAnnotation *addAnnotation;

@property (nonatomic, readonly) CGPoint menuPoint;

@property (nonatomic, readonly) CPDFPage *menuPage;

- (void)addAnnotation:(CPDFAnnotation *)annotation forPage:(CPDFPage *)page;

- (void)addAnnotation:(CPDFAnnotation *)annotation;

@end

NS_ASSUME_NONNULL_END
