//
//  CPDFTextPropertyCell.m
//  compdfkit-tools
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//


#import "CPDFTextPropertyCell.h"
#import "CPDFColorSelectView.h"
#import "CPDFOpacitySliderView.h"
#import "CPDFColorPickerView.h"

@interface CPDFTextPropertyCell()<CPDFColorSelectViewDelegate,CPDFOpacitySliderViewDelegate>
@property (weak, nonatomic) IBOutlet UIView *colorAreaView;
@property (nonatomic, strong) CPDFColorSelectView * colorView;
@property (weak, nonatomic) IBOutlet UIView *sliderArea;
@property (nonatomic, strong) CPDFOpacitySliderView * opacityView;
@property (nonatomic, strong) CPDFColorPickerView * colorPickerView;

@property (weak, nonatomic) IBOutlet UIButton *leftAlignBtn;
@property (weak, nonatomic) IBOutlet UIButton *centerAlignBtn;
@property (weak, nonatomic) IBOutlet UIButton *rightAlignBtn;


@end

@implementation CPDFTextPropertyCell


+(instancetype)CPDFTextPropertyCell {
    NSBundle *bundle = [NSBundle bundleForClass:[self class]];
    return [[bundle loadNibNamed:@"CPDFTextPropertyCell" owner:nil options:nil] lastObject];
}

- (void)awakeFromNib {
    [super awakeFromNib];
    // Initialization code
    if(!self.colorView){
        self.colorView  = [[CPDFColorSelectView alloc] initWithFrame:CGRectMake(10, 0, self.frame.size.width-20, 90)];
        self.colorView.autoresizingMask = UIViewAutoresizingFlexibleWidth;
        self.colorView.colorLabel.text = NSLocalizedString(@"Font Color:", nil);
        self.colorView.delegate = self;
        [self.colorAreaView addSubview:self.colorView];
    }
    

    if(!self.opacityView){
        self.opacityView = [[CPDFOpacitySliderView alloc] initWithFrame:CGRectMake(10, 0, self.frame.size.width-20, 90)];
        self.opacityView.autoresizingMask = UIViewAutoresizingFlexibleWidth;
        self.opacityView.titleLabel.text = NSLocalizedString(@"Font Size:", nil);
        self.opacityView.startLabel.text = @"0";
        self.opacityView.endLabel.text = @"100";
        self.opacityView.delegate = self;
        [self.sliderArea addSubview:self.opacityView];
    }
    
}

- (void)setSelected:(BOOL)selected animated:(BOOL)animated {
    [super setSelected:selected animated:animated];
    
    // Configure the view for the selected state
}

#pragma mark - CPDFColorSelectViewDelegate
- (void)selectColorView:(CPDFColorSelectView *)select {
    if(self.actionBlock){
        self.actionBlock(CPDFTextActionColorSelect);
    }
}

- (void)selectColorView:(CPDFColorSelectView *)select color:(UIColor *)color {
}

#pragma mark - OPacitySliderView
- (void)opacitySliderView:(CPDFOpacitySliderView *)opacitySliderView opacity:(CGFloat)opacity {
    NSLog(@"Opacity Slider! opacity%f",opacity);
}

#pragma mark - Action

- (IBAction)fontBoldAction:(UIButton *)sender {
    sender.selected = !sender.selected;
}

- (IBAction)fontItalicAction:(UIButton *)sender {
    sender.selected = !sender.selected;
}

- (IBAction)fontAlignmentAction:(UIButton *)sender {
    sender.selected = !sender.selected;
    
    if(sender == self.leftAlignBtn && sender.isSelected){
        [self.centerAlignBtn setSelected:NO];
        [self.rightAlignBtn setSelected:NO];
    }
    
    if(sender == self.centerAlignBtn && sender.isSelected){
        [self.rightAlignBtn setSelected:NO];
        [self.leftAlignBtn setSelected:NO];
    }
    
    if(sender == self.rightAlignBtn && sender.isSelected){
        [self.leftAlignBtn setSelected:NO];
        [self.centerAlignBtn setSelected:NO];
    }
}

- (IBAction)showFontNameAction:(UIButton *)sender {
    if(self.actionBlock){
        self.actionBlock(CPDFTextActionFontNameSelect);
    }
}



@end
