//
//  CPDFEditViewController.m
//  compdfkit-tools
//
//  Copyright © 2014-2023 PDF Technologies, Inc. All Rights Reserved.
//
//  THIS SOURCE CODE AND ANY ACCOMPANYING DOCUMENTATION ARE PROTECTED BY INTERNATIONAL COPYRIGHT LAW
//  AND MAY NOT BE RESOLD OR REDISTRIBUTED. USAGE IS BOUND TO THE ComPDFKit LICENSE AGREEMENT.
//  UNAUTHORIZED REPRODUCTION OR DISTRIBUTION IS SUBJECT TO CIVIL AND CRIMINAL PENALTIES.
//


#import "CPDFEditViewController.h"
#import "CPDFImagePropertyCell.h"
#import "CPDFTextPropertyCell.h"
#import "CPDFColorPickerView.h"
#import "CPDFEditFontNameSelectView.h"

@interface CPDFEditViewController ()<UITableViewDelegate,UITableViewDataSource,CPDFColorPickerViewDelegate,CPDFEditFontNameSelectViewDelegate>

@property (nonatomic, strong) UIView      * splitView;
@property (nonatomic, strong) UITableView * tableView;
@property (nonatomic, strong) CPDFColorPickerView * colorPickerView;
@property (nonatomic, strong) CPDFEditFontNameSelectView * fontSelectView;

@end

@implementation CPDFEditViewController

#pragma mark - Initializers


#pragma mark - ViewController Methods

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view.
    self.titleLabel = [[UILabel alloc] init];
    self.titleLabel.autoresizingMask = UIViewAutoresizingFlexibleRightMargin;
    self.titleLabel.text = NSLocalizedString(@"Image Property", nil);
    self.titleLabel.font = [UIFont systemFontOfSize:20];
    self.titleLabel.adjustsFontSizeToFitWidth = YES;
    [self.view addSubview:self.titleLabel];
    
    
    self.splitView  = [[UIView alloc] init];
    self.splitView.backgroundColor = [UIColor colorWithRed:245./255 green:245/255. blue:245/255. alpha:245/255.];
    [self.view addSubview:self.splitView];
    
    
    self.view.backgroundColor = [UIColor whiteColor];
    [self updatePreferredContentSizeWithTraitCollection:self.traitCollection];

}

- (void)viewWillLayoutSubviews {
    self.titleLabel.frame = CGRectMake((self.view.frame.size.width - 120)/2, 5, 120, 50);
    self.splitView.frame = CGRectMake(10, 60, self.view.frame.size.width-20, 3);
    
    if(!self.tableView){
        self.tableView = [[UITableView alloc] initWithFrame:CGRectMake(0, 70, self.view.frame.size.width, self.view.frame.size.height - 100)];
        self.tableView.delegate = self;
        [self.view addSubview:self.tableView];
        
        self.tableView.delegate = self;
        self.tableView.dataSource = self;
        [self.tableView reloadData];
    }

}

- (void)willTransitionToTraitCollection:(UITraitCollection *)newCollection withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator {
    [super willTransitionToTraitCollection:newCollection withTransitionCoordinator:coordinator];
    [self updatePreferredContentSizeWithTraitCollection:newCollection];
}

- (void)updatePreferredContentSizeWithTraitCollection:(UITraitCollection *)traitCollection
{
    if(self.editMode == CPDFEditModeText){
        self.preferredContentSize = CGSizeMake(self.view.bounds.size.width, traitCollection.verticalSizeClass == UIUserInterfaceSizeClassCompact ? 300 : 300);
    }else{
        self.preferredContentSize = CGSizeMake(self.view.bounds.size.width, traitCollection.verticalSizeClass == UIUserInterfaceSizeClassCompact ? 500 : 500);
    }

}

#pragma mark - UITableViewDelegate
- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return 1;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    if(self.editMode == CPDFEditModeText){
        static NSString *reuseIdentifier = @"CPDFTextPropertyCell";
        CPDFTextPropertyCell *cell = [tableView dequeueReusableCellWithIdentifier:reuseIdentifier];
        if (!cell) {
            cell = [CPDFTextPropertyCell CPDFTextPropertyCell];
        }
        cell.actionBlock = ^(CPDFTextActionType actionType) {
            if(actionType == CPDFTextActionColorSelect){
                //Add colorSelectView
                if(!self.colorPickerView){
                    self.colorPickerView = [[CPDFColorPickerView alloc] initWithFrame:self.view.frame];
                    self.colorPickerView.delegate = self;
                    self.colorPickerView.backgroundColor = [UIColor whiteColor];
                }
                [self.view addSubview:self.colorPickerView];
            }else if(actionType == CPDFTextActionFontNameSelect) {
                //Add actionFontNameSelect
                if(!self.fontSelectView){
                    self.fontSelectView = [[CPDFEditFontNameSelectView alloc] initWithFrame:self.view.bounds];
                    self.fontSelectView.delegate = self;
                    self.fontSelectView.backgroundColor = [UIColor whiteColor];
                }
                [self.view addSubview:self.fontSelectView];
            }
        };
        cell.selectionStyle = UITableViewCellSelectionStyleNone;
        tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
        return cell;
    }else{
        static NSString *reuseIdentifier = @"CPDFImagePropertyCell";
        CPDFImagePropertyCell *cell = [tableView dequeueReusableCellWithIdentifier:reuseIdentifier];
        if (!cell) {
            cell = [CPDFImagePropertyCell CPDFImagePropertyCell];
        }
        cell.selectionStyle = UITableViewCellSelectionStyleNone;
        tableView.separatorStyle = UITableViewCellSeparatorStyleNone;
        return cell;
    }

}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    if(self.editMode == CPDFEditModeText){
        return 300;
    }else{
        return 480;
    }
}

#pragma mark - ColorPickerDelegate
- (void)pickerView:(CPDFColorPickerView *)colorPickerView color:(UIColor *)color {
    NSLog(@"Select Picker!");
}

#pragma mark - setMode
- (void)setEditMode:(CPDFEditMode)editMode{
    _editMode = editMode;
    if(editMode == CPDFEditModeText){
        self.titleLabel.text =  NSLocalizedString(@"Text Property", nil);
    }else{
        self.titleLabel.text =  NSLocalizedString(@"Image Property", nil);
    }
    
    [self updatePreferredContentSizeWithTraitCollection:self.traitCollection];
}

#pragma mark - Accessors
- (void)addColorSelectView{
    
}

@end
